@@ -119,7 +119,7 @@ class CPDLC:
         self._cpdlc_connect_callback: Optional[Callable[[], None]] = None
         self._cpdlc_atc_info_update_callback: Optional[Callable[[], None]] = None
         self._cpdlc_disconnect_callback: Optional[Callable[[], None]] = None
-        self._network: Optional[Network] = None
+        self._network: Network = Network.UNKNOWN
         self._client = Client(timeout=10.0)
         self._state_lock = RLock()
         self._callback_executor = ThreadPoolExecutor(max_workers=max_workers)
@@ -292,6 +292,7 @@ class CPDLC:
         else:
             logger.trace(f"Full service provided")
             self._service_level = ServiceLevel.FULL
+            self._network = self.get_network()
         self.start_poller()
         self._service_initialization = True
 
@@ -397,7 +398,7 @@ class CPDLC:
         """
 
         @wraps(func)
-        def wrapper(self: CPDLC, *args: P.args, **kwargs: P.kwargs) -> R:
+        def wrapper(self: "CPDLC", *args: P.args, **kwargs: P.kwargs) -> R:
             if not self.is_official_service:
                 raise NoOfficialServerError()
             return func(self, *args, **kwargs)
@@ -413,7 +414,7 @@ class CPDLC:
         """
 
         @wraps(func)
-        def wrapper(self: CPDLC, *args: P.args, **kwargs: P.kwargs) -> R:
+        def wrapper(self: "CPDLC", *args: P.args, **kwargs: P.kwargs) -> R:
             if self._service_level != ServiceLevel.FULL:
                 logger.error("No full service available, cannot change network")
                 raise FullServiceRequiredError()
@@ -430,7 +431,7 @@ class CPDLC:
         """
 
         @wraps(func)
-        def wrapper(self: CPDLC, *args: P.args, **kwargs: P.kwargs) -> R:
+        def wrapper(self: "CPDLC", *args: P.args, **kwargs: P.kwargs) -> R:
             if not self._service_initialization:
                 raise NoInitializationError()
             return func(self, *args, **kwargs)
@@ -446,7 +447,7 @@ class CPDLC:
         """
 
         @wraps(func)
-        def wrapper(self: CPDLC, *args: P.args, **kwargs: P.kwargs) -> R:
+        def wrapper(self: "CPDLC", *args: P.args, **kwargs: P.kwargs) -> R:
             if self._callsign is None:
                 raise CallsignError()
             return func(self, *args, **kwargs)
@@ -463,7 +464,7 @@ class CPDLC:
 
         def decorator(func: Callable[P, R]) -> Callable[P, R]:
             @wraps(func)
-            def wrapper(self: CPDLC, *args: P.args, **kwargs: P.kwargs) -> R:
+            def wrapper(self: "CPDLC", *args: P.args, **kwargs: P.kwargs) -> R:
                 if self._cpdlc_connect_state not in states:
                     raise InvalidStateError(
                         f"Required states: {[s.name for s in states]}, "
@@ -516,7 +517,7 @@ class CPDLC:
             logger.error(f"Login code or email is invalid, please check login code or email")
             raise LoginError()
         selected = element.find("option", attrs={"selected": ""})
-        logger.debug(f"Current network: {selected}")
+        logger.debug(f"Current network: {selected.text}")
         return Network(selected.text)
 
     @_require_full_service
